@@ -11,8 +11,14 @@ function(
     t.threshold=2,
     set.REML.FALSE=TRUE,
     reset.REML.TRUE=TRUE,
-    file.name=paste("./full_backfitLMER_log_",gsub(" ","_",date()),".txt",sep="") # can also be FALSE to disable
+    file.name=paste("full_backfitLMER_log_",gsub(":","_",gsub(" ","_",date())),".txt",sep="") # or other path and file name or FALSE
     ){
+
+  current.dir=getwd()
+  temp.dir=tempdir()
+  tempdir()
+  setwd(temp.dir)
+
   if(file.name!=FALSE)sink(file=file.name,split=TRUE)  
   cat("======================================================\n")
   cat("===              backfitting fixed effects         ===\n")
@@ -22,14 +28,14 @@ function(
   }else{
     mod=bfFixefLMER_t.fnc(model=model,data=data,item=item,alpha=alpha,t.threshold=t.threshold,set.REML.FALSE=set.REML.FALSE,reset.REML.TRUE=FALSE,log.file=FALSE)
   }
-  cat("saving model to file",paste(getwd(),"/","temp_bfFixefLMER.RData",sep=""),"\n")
-  save(mod,file="temp_bfFixefLMER.RData")
+
+
   cat("======================================================\n")
   cat("===            forwardfitting random effects       ===\n")
   cat("======================================================\n")
   mod=ffRanefLMER.fnc(model=mod,data=data,ran.effects=ran.effects,alpha=alpha)
-  cat("saving model to file",paste(getwd(),"/","temp_ffRanefLMER.RData",sep=""),"\n")
-  save(mod,file="temp_ffRanefLMER.RData")
+
+
   cat("======================================================\n")
   cat("===            re-backfitting fixed effects        ===\n")
   cat("======================================================\n")
@@ -38,9 +44,13 @@ function(
   }else{
     mod=bfFixefLMER_t.fnc(model=mod,data=data,item=FALSE,alpha=alpha,t.threshold=t.threshold,set.REML.FALSE=FALSE,reset.REML.TRUE=reset.REML.TRUE,log.file=FALSE)
   }
-  cat("saving model to file",paste(getwd(),"/","temp_re_bfFixefLMER.RData",sep=""),"\n")
-  save(mod,file="temp_re_bfFixefLMER.RData")
-  if(file.name!=FALSE)sink(file=NULL)
+
+  if(file.name!=FALSE){
+    sink(file=NULL)
+    cat("Log file saved in directory",temp.dir,"\n")
+  }
+  setwd(current.dir)
+
   return(model=mod)
 }
 
